import requests
import json
from constants import GITHUB_TOKEN, GITHUB_ORG_NAME

def get_headers():
    # headers = {'Authorization': f'Bearer {GITHUB_TOKEN}', 'Accept': 'application/vnd.github+json'}
    return {'Authorization': f'token {GITHUB_TOKEN}'}

def get_organization_repositories():
    headers = get_headers()
    url = f'https://api.github.com/orgs/{GITHUB_ORG_NAME}/repos'
    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        return response.json()
    else:
        print(f"Error fetching organization repositories. Status code: {response.status_code}")
        return None

def get_autolink_rules(repo_name):
    headers = get_headers()
    url = f'https://api.github.com/repos/{GITHUB_ORG_NAME}/{repo_name}/autolinks'
    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        return response.json()
    else:
        print(f"Error fetching autolink rules for repository {repo_name}. Status code: {response.status_code}")
        return None
    
def remove_autolink_rule(rule_id, repo_name):
    headers = get_headers()
    delete_url = f'https://api.github.com/repos/{GITHUB_ORG_NAME}/{repo_name}/autolinks/{rule_id}'
    response = requests.delete(delete_url, headers=headers)

    if response.status_code == 204:
        print(f"Auto-link rule {rule_id} removed successfully.")
    else:
        print(f"Error removing auto-link rule {rule_id}. Status code: {response.status_code}")

    
def remove_all_autolink_rules(repo_name):
    existingRules = get_autolink_rules(repo_name=repo_name)

    # Remove each auto-link rule
    for rule in existingRules:
        rule_id = rule['id']
        
        headers = {'Authorization': f'Bearer {GITHUB_TOKEN}', 'Accept': 'application/vnd.github+json'}
        delete_url = f'https://api.github.com/repos/{GITHUB_ORG_NAME}/{repo_name}/autolinks/{rule_id}'
        response = requests.delete(delete_url, headers=headers)

        if response.status_code == 204:
            print(f"Auto-link rule {rule_id} removed successfully.")
        else:
            print(f"Error removing auto-link rule {rule_id}. Status code: {response.status_code}")

def add_autolink_rule(repo_name, key_prefix, url_template, is_alphanumeric):
    headers = get_headers()
    url = f'https://api.github.com/repos/{GITHUB_ORG_NAME}/{repo_name}/autolinks'
    payload = {
        'key_prefix': key_prefix,
        'url_template': url_template,
        "is_alphanumeric": is_alphanumeric
    }

    response = requests.post(url, headers=headers, data=json.dumps(payload))

    if response.status_code == 201:
        print(f"Autolink rule added for {key_prefix} in repository {repo_name}.")
    else:
        print(f"Error adding autolink rule for {key_prefix} in repository {repo_name}. Status code: {response.status_code}")
        