import requests
from requests.auth import HTTPBasicAuth
from constants import JIRA_BASE_URL, JIRA_USERNAME, JIRA_API_TOKEN

def get_all_jira_projects():
    try:
        url = f'{JIRA_BASE_URL}/rest/api/3/project/search'
        auth = HTTPBasicAuth(JIRA_USERNAME, JIRA_API_TOKEN)

        start_at = 0
        max_results = 50
        all_projects = []

        while True:
            params = {'startAt': start_at, 'maxResults': max_results}
            response = requests.get(url, auth=auth, params=params)
            response.raise_for_status()

            responseJson = response.json()
            projects_page = responseJson['values']
            all_projects.extend(projects_page)

            start_at += max_results
            if start_at >= response.json()['total']:
                break

        return all_projects

    except requests.exceptions.RequestException as e:
        print(f"Error fetching Jira projects: {e}")
        return []