from jira_api import *
from github_api import *
from constants import *


def get_repositories_names():
    allRepos = get_organization_repositories()
    repoNames = list(map(lambda repo: repo["name"], allRepos))
    return repoNames

def get_jira_projects_keys():
    allProjects = get_all_jira_projects()
    allKeys = list(map(lambda project: project["key"] + "-", allProjects))
    return allKeys
   
def add_missing_autolink_rules(repo_name, existing_rules, all_jira_codes):
    missing_rules = [jira_code for jira_code in all_jira_codes if jira_code not in existing_rules]
    
    if not missing_rules:
        print(f"All autolink rules for repository {repo_name} are already present.")
        return
    
    for jira_code in missing_rules:
        add_autolink_rule(
            repo_name=repo_name,
            key_prefix=jira_code,
            url_template=f'{JIRA_BASE_URL}/browse/{jira_code}<num>',
            is_alphanumeric=False
        )
        
def setup_jira_autolinks():
    jiraKeys = get_jira_projects_keys()
    repositoryNames = get_repositories_names()
    
    if repositoryNames:
        for repo_name in repositoryNames:
            autolink_rules = get_autolink_rules(repo_name)

            if autolink_rules is not None:
                existing_rules = [rule['key_prefix'] for rule in autolink_rules]
                add_missing_autolink_rules(repo_name, existing_rules, jiraKeys)
                
def remove_all_autolink_rules():
    repositoryNames = get_repositories_names()
    for repoName in repositoryNames:
        autolink_rules = get_autolink_rules(repoName)
        for rule in autolink_rules:
            remove_autolink_rule(
                rule_id=rule["id"],
                repo_name=repoName,
            )
        
def main():
    setup_jira_autolinks()

if __name__ == '__main__':
    main()
